#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Oct 14 09:23:07 2020
@author: Ajit Johnson Nirmal
This function will allow users to calculate the average distance between phenotypes/clusters
of interest. It is also possible to compare between ROI's within an image or across images.
"""

# Import library


# Function